@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct BufConfig<'a> {
     pub format: &'a str,
@@ -17,9 +21,9 @@ pub struct BufConfig<'a> {
 impl<'a> Default for BufConfig<'a> {
     fn default() -> Self {
         BufConfig {
-            format: "with [$symbol ($version)]($style)",
+            format: "with [$symbol($version )]($style)",
             version_format: "v${raw}",
-            symbol: "",
+            symbol: "🦬 ",
             style: "bold blue",
             disabled: false,
             detect_extensions: vec![],
