@@ -43,6 +43,7 @@ mod line_break;
 mod localip;
 mod lua;
 mod memory_usage;
+mod meson;
 mod nim;
 mod nix_shell;
 mod nodejs;
@@ -137,6 +138,7 @@ pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
             "localip" => localip::module(context),
             "lua" => lua::module(context),
             "memory_usage" => memory_usage::module(context),
+            "meson" => meson::module(context),
             "nim" => nim::module(context),
             "nix_shell" => nix_shell::module(context),
             "nodejs" => nodejs::module(context),
@@ -242,6 +244,9 @@ pub fn description(module: &str) -> &'static str {
         "localip" => "The currently assigned ipv4 address",
         "lua" => "The currently installed version of Lua",
         "memory_usage" => "Current system memory and swap usage",
+        "meson" => {
+            "The current Meson environment, if $MESON_DEVENV and $MESON_PROJECT_NAME are set"
+        }
         "nim" => "The currently installed version of Nim",
         "nix_shell" => "The nix-shell environment",
         "nodejs" => "The currently installed version of NodeJS",
